# Generated by roxygen2: do not edit by hand

S3method(print,MertonPrice)
export(MertonModel)
export(diagnosticPlots)
export(fit)
export(fitMerton)
export(jdSampleData)
export(jumpMoments)
export(loglik)
export(mertonLogLik)
export(priceEuropean)
export(simulate)
export(simulateMerton)
exportClasses(JDFitResult)
exportClasses(JDSimResult)
exportClasses(JumpDiffModel)
exportClasses(MertonModel)
exportMethods(confint)
exportMethods(jumpMoments)
exportMethods(show)
import(methods)
importFrom(ggplot2,aes)
importFrom(ggplot2,after_stat)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_density)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,theme_minimal)
importFrom(numDeriv,hessian)
importFrom(stats,acf)
importFrom(stats,density)
importFrom(stats,dnorm)
importFrom(stats,dpois)
importFrom(stats,lag)
importFrom(stats,median)
importFrom(stats,optim)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,sd)
importFrom(stats,simulate)
