% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/merton_model.R
\docType{class}
\name{JumpDiffModel-class}
\alias{JumpDiffModel-class}
\title{JumpDiffModel: Virtual Base Class for Jump-Diffusion Models}
\description{
Abstract base class. Do not instantiate directly.
Concrete subclasses: \linkS4class{MertonModel}.
}
\section{Slots}{

\describe{
\item{\code{mu}}{Numeric. Drift parameter (annualised).}

\item{\code{sigma}}{Positive numeric. Diffusion volatility.}

\item{\code{lambda}}{Non-negative numeric. Jump intensity (jumps per year).}
}}

