% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/merton_model.R
\name{MertonModel}
\alias{MertonModel}
\title{Create a MertonModel Object}
\usage{
MertonModel(mu = 0.05, sigma = 0.2, lambda = 1, mu_j = -0.1, sigma_j = 0.15)
}
\arguments{
\item{mu}{Numeric. Drift (default 0.05).}

\item{sigma}{Positive numeric. Diffusion volatility (default 0.20).}

\item{lambda}{Non-negative numeric. Jump intensity (default 1).}

\item{mu_j}{Numeric. Mean log-jump size (default -0.10).}

\item{sigma_j}{Positive numeric. Std dev of log-jumps (default 0.15).}
}
\value{
A validated \linkS4class{MertonModel} object.
}
\description{
Create a MertonModel Object
}
\examples{
m <- MertonModel(mu = 0.05, sigma = 0.20, lambda = 1,
                 mu_j = -0.10, sigma_j = 0.15)
show(m)

}
