% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generics.R
\name{simulate}
\alias{simulate}
\title{Simulate Asset Price Paths}
\usage{
simulate(object, n, T_, steps, seed = NULL, ...)
}
\arguments{
\item{object}{A \linkS4class{JumpDiffModel} object.}

\item{n}{Integer. Number of simulated paths.}

\item{T_}{Positive numeric. Time horizon in years.}

\item{steps}{Positive integer. Number of time steps.}

\item{seed}{Optional integer seed for reproducibility.}

\item{...}{Additional arguments passed to methods.}
}
\value{
A \linkS4class{JDSimResult} object.
}
\description{
Simulate Asset Price Paths
}
